@@ -13,12 +13,4 @@ __all__ = (
 from dungeonsheets import background, features, race, spells, weapons, mechanics
 from dungeonsheets.character import Character
 from dungeonsheets.content_registry import import_homebrew
-
-import os
-
-
-def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname)).read()
-
-
-__version__ = read("../VERSION")
+from dungeonsheets.content import __version__
