@@ -24,3 +24,14 @@ class JSONFormatError(RuntimeError):
 
 class UnknownFileType(RuntimeError):
     """The input file does not match one of the known formats."""
+
+
+class UnknownOutputFormat(RuntimeError):
+    """The output format requested is not one of the known outputs."""
+
+
+class ContentNotFound(ValueError):
+    """The requested content could not be resolved."""
+
+class AmbiguousContent(ValueError):
+    """Multiple valid content entries were found."""
