@@ -8,15 +8,10 @@ class _SpecialistSpells(Feature):
     Spells table. These spells count as artificer spells for you, but they
     don't count against the number of artificer spells you prepare.
     """
+
     _name = "Select One"
     source = "Artificer"
-    _spells = {
-            3: [],
-            5: [],
-            9: [],
-            13: [],
-            17: []
-            }
+    _spells = {3: [], 5: [], 9: [], 13: [], 17: []}
     spells_known = []
     spells_prepared = []
 
@@ -80,32 +75,33 @@ class FirearmProficiency(Feature):
 
 class MagicalTinkering(Feature):
     """At 1st level, you learn how to invest a spark of magic into mundane
-    objects. To use this ability, you must have tinker's tools or other
-    artisan's tools  in hand. You then touch a Tiny nonmagical object as an
-    action and give it one of the following magical properties of your choice:
+    objects. To use this ability, you must have tinker's tools or
+    other artisan's tools in hand. You then touch a Tiny nonmagical
+    object as an action and give it one of the following magical
+    properties of your choice:
 
-    - The object sheds bright light in a 5-foot radius and dim light for an
-      additional 5 fe et.
+    - The object sheds bright light in a 5-foot radius and dim light
+      for an additional 5 feet.
+    - Whenever tapped by a creature, the object emits a recorded
+      message that can be heard up to 10 feet away. You utter the
+      message when you bestow this property on the object, and the
+      recording can be no more than 6 seconds long.
+    - The object continuously emits your choice of an odor or a
+      nonverbal sound (wind, waves, chirping, or the like). The chosen
+      phenomenon is perceivable up to 10 feet away.
+    - A static visual effect appears on one of the object's
+      surfaces. This effect can be a picture, up to 25 words of text,
+      lines and shapes, or a mixture of these elements, as you
+      like. The chosen property lasts indefinitely. As an action, you
+      can touch the object and end the property early. You can bestow
+      magic on multiple objects, touching one object each time you use
+      this feature, though a single object can only bear one property
+      at a time. The maximum number of objects you can affect with
+      this feature at one time is equal to your Intelligence modifier
+      (minimum of one object). If you try to exceed your maximum, the
+      oldest property immediately ends, and then the new property
+      applies.
 
-    - Whenever tapped by a creature, the object emits a recorded message that
-      can be heard up to 10 feet away. You utter the message when you bestow
-      this property on the object, and the recording can be no more than 6
-      seconds long.
-
-    - The object continuously emits your choice of an odor or a nonverbal sound
-      (wind, waves, chirping, or the like). The chosen phenomenon is
-      perceivable up to 10 feet away.
-
-    - A static visual effect appears on one of the object's surfaces. This
-      effect can be a picture, up to 25 words of text, lines and shapes, or a
-      mixture of these elements, as you like. The chosen property lasts
-      indefinitely. As an action, you can touch the object and end the property
-      early. You can bestow magic on multiple objects, touching one object each
-      time you use this feature, though a single object can only bear one
-      property at a time. The maximum number of objects you can affect with
-      this feature at one time is equal to your Intelligence modifier (minimum
-      of one object). If you try to exceed your maximum, the oldest property
-      immediately ends, and then the new property applies.
     """
 
     name = "Magical Tinkering"
@@ -117,59 +113,62 @@ class InfuseItem(Feature):
     magical infusions. The magic items you create with this feature are
     effectively prototypes of permanent items.
 
-    **Infusions known**
-    When you gain this feature, pick four artificer infusions
-    to learn, choosing from the "Artificer Infusions" section at the end of the
-    class's description. You learn additional infusions of your choice when you
-    reach certain levels in this class, as shown in the Infusions Known column
-    of the Artificer table. Whenever you gain a level in this class, you can
-    re­place one of the artificer infusions you learned with a new one.
+    Infusions known
+      When you gain this feature, pick four artificer infusions to
+      learn, choosing from the "Artificer Infusions" section at the
+      end of the class's description. You learn additional infusions
+      of your choice when you reach certain levels in this class, as
+      shown in the Infusions Known column of the Artificer
+      table. Whenever you gain a level in this class, you can re­place
+      one of the artificer infusions you learned with a new one.
+    Infusing an item
+      Whenever you finish a long rest, you can touch a non­magical
+      object and imbue it with one of your artificer in­fusions,
+      turning it into a magic item. An infusion works on only certain
+      kinds of objects, as specified in the infusion's description. If
+      the item requires attunement, you can attune yourself to it the
+      instant you infuse the item. If you decide to attune to the item
+      later, you must do so using the normal process for attunement
+      (see "Attunement" in chapter 7 of the Dungeon Master's Guide).
+      Your infusion remains in an item indefinitely, but when you die,
+      the infusion vanishes after a number of days have passed equal
+      to your Intelligence modifier (minimum of 1 day). The infusion
+      also vanishes if you give up your knowledge of the infusion for
+      another one. You can infuse more than one nonmagical object at
+      the end of a long rest; the maximum number of objects appears in
+      the Infused Items column of the Artificer table. You must touch
+      each of the objects, and each of your infusions can be in only
+      one object at a time. Moreover, no object can bear more than one
+      of your infusions at a time. If you try to exceed your maximum
+      number of in­fusions, the oldest infusion immediately ends, and
+      then the new infusion applies.
 
-    **Infusing an item**
-    Whenever you finish a long rest, you can touch a non­magical object and
-    imbue it with one of your artificer in­fusions, turning it into a magic
-    item. An infusion works on only certain kinds of objects, as specified in
-    the infusion's description. If the item requires attunement, you can
-    attune yourself to it the instant you infuse the item. If you decide to
-    attune to the item later, you must do so using the normal process for
-    attunement (see "Attunement" in chapter 7 of the Dungeon Master's Guide).
-    Your infusion remains in an item indefinitely, but when you die, the
-    infusion vanishes after a number of days have passed equal to your
-    Intelligence modifier (minimum of 1 day). The infusion also vanishes if you
-    give up your knowledge of the infusion for another one. You can infuse more
-    than one nonmagical object at the end of a long rest; the maximum number of
-    objects appears in the Infused Items column of the Artificer table. You
-    must touch each of the objects, and each of your infusions can be in only
-    one object at a time. Moreover, no object can bear more than one of your
-    infusions at a time. If you try to exceed your maximum number of
-    in­fusions, the oldest infusion immediately ends, and then the new
-    infusion applies.
     """
 
     _name = "Infuse Item"
     source = "Artificer"
     _infusions = {
-            # level: (infusions known, infused items)
-            2:  (4, 2),
-            3:  (4, 2),
-            4:  (4, 2),
-            5:  (4, 2),
-            6:  (6, 3),
-            7:  (6, 3),
-            8:  (6, 3),
-            9:  (6, 3),
-            10: (8, 4),
-            11: (8, 4),
-            12: (8, 4),
-            13: (8, 4),
-            14: (10, 5),
-            15: (10, 5),
-            16: (10, 5),
-            17: (10, 5),
-            18: (12, 6),
-            19: (12, 6),
-            20: (12, 6),
-            }
+        # level: (infusions known, infused items)
+        2: (4, 2),
+        3: (4, 2),
+        4: (4, 2),
+        5: (4, 2),
+        6: (6, 3),
+        7: (6, 3),
+        8: (6, 3),
+        9: (6, 3),
+        10: (8, 4),
+        11: (8, 4),
+        12: (8, 4),
+        13: (8, 4),
+        14: (10, 5),
+        15: (10, 5),
+        16: (10, 5),
+        17: (10, 5),
+        18: (12, 6),
+        19: (12, 6),
+        20: (12, 6),
+    }
 
     @property
     def name(self):
@@ -213,14 +212,16 @@ class ToolExpertise(Feature):
 
 
 class FlashOfGenius(Feature):
-    """Starting at 7th level, you gain the ability to come up with solutions
-    under pressure. When you or another creature you can see within 30 feet of
-    you makes an ability check or a saving throw, you can use your reaction to
-    add your Intelligence modifier to the roll.
+    """Starting at 7th level, you gain the ability to come up with
+    solutions under pressure. When you or another creature you can see
+    within 30 feet of you makes an ability check or a saving throw,
+    you can use your reaction to add your Intelligence modifier to the
+    roll.
+
+    You can use this feature a number of times equal to your
+    Intelligence modifier (minimum of once). You regain all expended
+    uses when you finish a long rest.
 
-    You can use this feature a number of times equal to your Intelligence
-    modifier (minimum of once). You regain all expended uses when you finish a
-    long rest.
     """
 
     name = "Flash Of Genius"
@@ -232,10 +233,10 @@ class MagicItemAdept(Feature):
     to use and make magic items:
 
     - You can attune to up to four magic items at once.
+    - If you craft a magic item with a rarity of common or uncommon,
+      it takes you a quarter of the normal time, and it costs you half
+      as much of the usual gold.
 
-    - If you craft a magic item with a rarity of common or uncommon, it takes
-      you a quarter of the normal time, and it costs you half as much of the
-      usual gold.
     """
 
     name = "Magic Item Adept"
@@ -243,18 +244,20 @@ class MagicItemAdept(Feature):
 
 
 class SpellStoringItem(Feature):
-    """At 11th level, you learn how to store a spell in an object. Whenever you
-    finish a long rest, you can touch one simple or martial weapon or one item
-    that you can use as a spellcasting focus, and you store a spell in it,
-    choosing a 1st- or 2nd-level spell from the artificer spell list that
-    requires 1 action to cast (you needn't have it prepared).
+    """At 11th level, you learn how to store a spell in an
+    object. Whenever you finish a long rest, you can touch one simple
+    or martial weapon or one item that you can use as a spellcasting
+    focus, and you store a spell in it, choosing a 1st- or 2nd-level
+    spell from the artificer spell list that requires 1 action to cast
+    (you needn't have it prepared).
 
-    While holding the object, a creature can take an action to produce the
-    spell's effect from it, using your spellcasting ability modifier. If the
-    spell requires concentration, the creature must concentrate. The spell
-    stays in the object until it's been used a number of times equal to twice
-    your Intelligence modifier (minimum of twice) or until you use this fe
-    ature again to store a spell in an object.
+    While holding the object, a creature can take an action to produce
+    the spell's effect from it, using your spellcasting ability
+    modifier. If the spell requires concentration, the creature must
+    concentrate. The spell stays in the object until it's been used a
+    number of times equal to twice your Intelligence modifier (minimum
+    of twice) or until you use this fe ature again to store a spell in
+    an object.
     """
 
     name = "Spell-Storing Item"
@@ -265,9 +268,9 @@ class MagicItemSavant(Feature):
     """At 14th level, your skill with magic items deepens more:
 
     - You can attune to up to five magic items at once.
+    - You ignore all class, race, spell, and level requirements on
+      attuning to or using a magic item.
 
-    - You ignore all class, race, spell, and level requirements on attuning to
-      or using a magic item.
     """
 
     name = "Magic Item Savant"
@@ -289,10 +292,10 @@ class SoulOfArtifice(Feature):
 
     - You gain a +1 bonus to all saving throws per magic item you are currently
       attuned to.
+    - If you're reduced to 0 hit points but not killed out­right, you
+      can use your reaction to end one of your artificer infusions,
+      causing you to drop to 1 hit point instead of 0.
 
-    - If you're reduced to 0 hit points but not killed out­right, you can use
-      your reaction to end one of your artificer infusions, causing you to drop
-      to 1 hit point instead of 0.
     """
 
     name = "Soul of Artifice"
@@ -319,12 +322,12 @@ class AlchemistSpells(_SpecialistSpells):
 
     _name = "Alchemist"
     _spells = {
-            3: [spells.HealingWord, spells.RayOfSickness],
-            5: [spells.FlamingSphere, spells.MelfsAcidArrow],
-            9: [spells.GaseousForm, spells.MassHealingWord],
-            13: [spells.Blight, spells.DeathWard],
-            17: [spells.Cloudkill, spells.RaiseDead]
-            }
+        3: [spells.HealingWord, spells.RayOfSickness],
+        5: [spells.FlamingSphere, spells.MelfsAcidArrow],
+        9: [spells.GaseousForm, spells.MassHealingWord],
+        13: [spells.Blight, spells.DeathWard],
+        17: [spells.Cloudkill, spells.RaiseDead],
+    }
 
 
 class ExperimentalElixir(Feature):
@@ -388,18 +391,18 @@ class AlchemicalSavant(Feature):
 
 
 class RestorativeReagents(Feature):
-    """Starting at 9th level, you can incorporate
-    restorative reagents into some of your works:
+    """Starting at 9th level, you can incorporate restorative reagents
+    into some of your works:
 
-    - Whenever a creature drinks an experimental elixir you created, the
-      creature gains temporary hit points equal to 2d6 + your Intelligence
-      modifier (minimum of 1 temporary hit point).
+    - Whenever a creature drinks an experimental elixir you created,
+      the creature gains temporary hit points equal to 2d6 + your
+      Intelligence modifier (minimum of 1 temporary hit point).
+    - You can cast lesser restoration without expending a spell slot
+      and without preparing the spell, provided you use alchemist's
+      supplies as the spellcasting focus. You can do so a number of
+      times equal to your Intelligence modifier (minimum of once), and
+      you regain all expended uses when you finish a long rest.
 
-    - You can cast lesser restoration without expending a spell slot and
-      without preparing the spell, provided you use alchemist's supplies as the
-      spellcasting focus. You can do so a number of times equal to your
-      Intelligence modifier (minimum of once), and you regain all expended uses
-      when you finish a long rest.
     """
 
     name = "Restorative Reagents"
@@ -408,17 +411,18 @@ class RestorativeReagents(Feature):
 
 class ChemicalMastery(Feature):
     """By 15th level, you have been exposed to so many chemicals that they
-    pose little risk to you, and you can use them to quickly end certain
-    ailments:
+    pose little risk to you, and you can use them to quickly end
+    certain ailments:
 
-    - You gain resistance to acid damage and poison damage, and you are immune
-      to the poisoned condition.
+    - You gain resistance to acid damage and poison damage, and you
+      are immune to the poisoned condition.
+    - You can cast greater restoration and heal without expending a
+      spell slot, without preparing the spell, and without material
+      components, provided you use alchemist's supplies as the
+      spellcasting focus. Once you cast either spell with this
+      feature, you can't cast that spell with it again until you
+      finish a long rest.
 
-    - You can cast greater restoration and heal without expending a spell
-      slot, without preparing the spell, and without material components,
-      provided you use alchemist's supplies as the spellcasting focus. Once
-      you cast either spell with this feature, you can't cast that spell with
-      it again until you finish a long rest.
     """
 
     name = "Chemical Mastery"
@@ -435,12 +439,12 @@ class ArtilleristSpells(_SpecialistSpells):
 
     _name = "Artillerist"
     _spells = {
-            3: [spells.Shield, spells.Thunderwave],
-            5: [spells.ScorchingRay, spells.Shatter],
-            9: [spells.Fireball, spells.WindWall],
-            13: [spells.IceStorm, spells.WallOfFire],
-            17: [spells.ConeOfCold, spells.WallOfForce]
-            }
+        3: [spells.Shield, spells.Thunderwave],
+        5: [spells.ScorchingRay, spells.Shatter],
+        9: [spells.Fireball, spells.WindWall],
+        13: [spells.IceStorm, spells.WallOfFire],
+        17: [spells.ConeOfCold, spells.WallOfForce],
+    }
 
 
 class ArtilleristToolProficiency(Feature):
@@ -504,17 +508,19 @@ class EldritchCannon(Feature):
 
 
 class ArcaneFirearm(Feature):
-    """At 5th level, you know how to turn a wand, staff, or rod into an arcane
-    firearm, a conduit for your destructive spells. When you finish a long
-    rest, you can use wood­carver's tools to carve special sigils into a wand,
-    staff, or rod and thereby turn it into your arcane firearm. The sigils
-    disappear from the object if you later carve them on a different item. The
-    sigils otherwise last indefinitely.
+    """At 5th level, you know how to turn a wand, staff, or rod into an
+    arcane firearm, a conduit for your destructive spells. When you
+    finish a long rest, you can use wood­carver's tools to carve
+    special sigils into a wand, staff, or rod and thereby turn it into
+    your arcane firearm. The sigils disappear from the object if you
+    later carve them on a different item. The sigils otherwise last
+    indefinitely.
+
+    You can use your arcane firearm as a spellcasting focus for your
+    artificer spells. When you cast an artificer spell through the
+    firearm, roll a d8, and you gain a bonus to one of the spell's
+    damage rolls equal to the number rolled.
 
-    You can use your arcane firearm as a spellcasting focus for your artificer
-    spells. When you cast an artificer spell through the firearm, roll a d8,
-    and you gain a bonus to one of the spell's damage rolls equal to the
-    number rolled.
     """
 
     name = "Arcane Firearm"
@@ -526,12 +532,12 @@ class ExplosiveCannon(Feature):
     destructive:
 
     - The cannon's damage rolls all increase by 1d8.
+    - As an action, you can command the cannon to detonate if you are
+      within 60 feet of it. Doing so destroys the cannon and forces
+      each creature within 20 feet of it to make a Dexterity saving
+      throw against your spell save DC, taking 3d8 force damage on a
+      failed save or half as much damage on a successful one.
 
-    - As an action, you can command the cannon to detonate if you are within 60
-      feet of it. Doing so destroys the cannon and forces each creature within
-      20 feet of it to make a Dexterity saving throw against your spell save
-      DC, taking 3d8 force damage on a failed save or half as much damage on a
-      successful one.
     """
 
     name = "Explosive Cannon"
@@ -542,15 +548,15 @@ class FortifiedPosition(Feature):
     """Starting at 15th level, you're a master at forming well-defended
     emplacements using Eldritch Cannon:
 
-    - You and your allies have half cover while within 10 feet of a cannon you
-      create with Eldritch Cannon, as a result of a shimmering field of magical
-      protection that the cannon emits.
+    - You and your allies have half cover while within 10 feet of a
+      cannon you create with Eldritch Cannon, as a result of a
+      shimmering field of magical protection that the cannon emits.
+    - You can now have two cannons at the same time. You can create
+      two with the same action (but not the same spell slot), and you
+      can activate both of them with the same bonus action. You
+      determine whether the cannons are identical to each other or
+      different. You can't create a third cannon while you have two.
 
-    - You can now have two cannons at the same time. You can create two with
-      the same action (but not the same spell slot), and you can activate both
-      of them with the same bonus action. You determine whether the cannons are
-      identical to each other or different. You can't create a third cannon
-      while you have two.
     """
 
     name = "Fortified Position"
@@ -559,26 +565,30 @@ class FortifiedPosition(Feature):
 
 # Battle Smith
 class BattleSmithSpells(_SpecialistSpells):
-    """Starting at 3rd level, you always have certain spells prepared after you
-    reach particular levels in this class, as shown in the Battle Smith Spells
-    table. These spells count as artificer spells for you, but they don't count
-    against the number of artificer spells you prepare.
+    """Starting at 3rd level, you always have certain spells prepared
+    after you reach particular levels in this class, as shown in the
+    Battle Smith Spells table. These spells count as artificer spells
+    for you, but they don't count against the number of artificer
+    spells you prepare.
+
     """
 
     _name = "Battle Smith"
     _spells = {
-            3: [spells.Heroism, spells.Shield],
-            5: [spells.BrandingSmite, spells.WardingBond],
-            9: [spells.AuraOfVitality, spells.ConjureBarrage],
-            13: [spells.AuraOfPurity, spells.FireShield],
-            17: [spells.BanishingSmite, spells.MassCureWounds]
-            }
+        3: [spells.Heroism, spells.Shield],
+        5: [spells.BrandingSmite, spells.WardingBond],
+        9: [spells.AuraOfVitality, spells.ConjureBarrage],
+        13: [spells.AuraOfPurity, spells.FireShield],
+        17: [spells.BanishingSmite, spells.MassCureWounds],
+    }
 
 
 class BattleSmithToolProficiency(Feature):
-    """When you adopt this specialization at 3rd level, you gain proficiency
-    with smith's tools. If you already have this proficiency, you gain
-    proficiency with one other type of artisan's tools of your choice.
+    """When you adopt this specialization at 3rd level, you gain
+    proficiency with smith's tools. If you already have this
+    proficiency, you gain proficiency with one other type of artisan's
+    tools of your choice.
+
     """
 
     name = "Tool Proficiency"
@@ -590,10 +600,10 @@ class BattleReady(Feature):
     magic have paid off in two ways:
 
     - You gain proficiency with martial weapons.
+    - When you attack with a magic weapon, you can use your
+      Intelligence modifier, instead of Strength or Dexterity
+      modifier, for the attack and damage rolls.
 
-    - When you attack with a magic weapon, you can use your Intelligence
-      modifier, instead of Strength or Dexterity modifier, for the attack and
-      damage rolls.
     """
 
     name = "Battle Ready"
@@ -601,28 +611,31 @@ class BattleReady(Feature):
 
 
 class SteelDefender(Feature):
-    """By 3rd level, your tinkering has borne you a faithful companion, a steel
-    defender. It is friendly to you and your companions, and it obeys your
-    commands. See this creature's game statistics in the steel defender stat
-    block. You determine the creature's appearance and whether it has two legs
-    or fo ur; your choice has no effect on its game statistics.
+    """By 3rd level, your tinkering has borne you a faithful companion, a
+    steel defender. It is friendly to you and your companions, and it
+    obeys your commands. See this creature's game statistics in the
+    steel defender stat block. You determine the creature's appearance
+    and whether it has two legs or four; your choice has no effect on
+    its game statistics.
 
-    In combat, the steel defender shares your initiative count, but it takes
-    its turn immediately after yours. It can move and use its reaction on its
-    own, but the only action it takes on its turn is the Dodge action, unless
-    you take a bonus action on your turn to command it to take one of the
-    actions in its stat block or the Dash, Disengage, Help, Hide, or Search
-    action.
+    In combat, the steel defender shares your initiative count, but it
+    takes its turn immediately after yours. It can move and use its
+    reaction on its own, but the only action it takes on its turn is
+    the Dodge action, unless you take a bonus action on your turn to
+    command it to take one of the actions in its stat block or the
+    Dash, Disengage, Help, Hide, or Search action.
 
-    If the *mending* spell is cast on it, it regains 2d6 hit points. If it has
-    died within the last hour, you can use your smith's tools as an action to
-    revive it, provided you are within 5 feet of it and you expend a spell slot
-    of 1st level or higher. The steel defender returns to life after 1 minute
-    with all its hit points restored.
+    If the *mending* spell is cast on it, it regains 2d6 hit
+    points. If it has died within the last hour, you can use your
+    smith's tools as an action to revive it, provided you are within 5
+    feet of it and you expend a spell slot of 1st level or higher. The
+    steel defender returns to life after 1 minute with all its hit
+    points restored.
+
+    At the end of a long rest, you can create a new steel defender if
+    you have your smith's tools with you. If you already have a steel
+    defender from this feature, the first one immediately perishes.
 
-    At the end of a long rest, you can create a new steel defender if you have
-    your smith's tools with you. If you already have a steel defender from this
-    feature, the first one immediately perishes.
     """
 
     name = "Steel Defender"
@@ -630,8 +643,9 @@ class SteelDefender(Feature):
 
 
 class ExtraAttackBattleSmith(Feature):
-    """Starting at 5th level, you can attack twice, rather than once, whenever
-    you take the Attack action on your turn.
+    """Starting at 5th level, you can attack twice, rather than once,
+    whenever you take the Attack action on your turn.
+
     """
 
     name = "Extra Attack"
@@ -639,18 +653,19 @@ class ExtraAttackBattleSmith(Feature):
 
 
 class ArcaneJolt(Feature):
-    """At 9th level, you learn new ways to channel arcane energy to harm or
-    heal. When either you hit a target with a magic weapon attack or your steel
-    defender hits a target, you can channel magical energy through the strike
-    to create one of the following effects:
+    """At 9th level, you learn new ways to channel arcane energy to harm
+    or heal. When either you hit a target with a magic weapon attack
+    or your steel defender hits a target, you can channel magical
+    energy through the strike to create one of the following effects:
 
     - The target takes an extra 2d6 force damage.
+    - Choose one creature or object you can see within 30 feet of the
+      target.  Healing energy flows into the chosen recipient,
+      restoring 2d6 hit points to it. You can use this energy a number
+      of times equal to your Intelligence modifier (minimum of once),
+      but you can do so no more than once on a turn. You regain all
+      expended uses when you finish a long rest
 
-    - Choose one creature or object you can see within 30 feet of the target.
-      Healing energy flows into the chosen recipient, restoring 2d6 hit points
-      to it. You can use this energy a number of times equal to your
-      Intelligence modifier (minimum of once), but you can do so no more than
-      once on a turn. You regain all expended uses when you finish a long rest
     """
 
     name = "Arcane Jolt"
@@ -661,13 +676,13 @@ class ImprovedDefender(Feature):
     """At 15th level, your Arcane jolt and steel defender be­come more
     powerful:
 
-    - The extra damage and the healing of your Arcane jolt both increase to
-      4d6.
-
+    - The extra damage and the healing of your Arcane jolt both
+      increase to 4d6.
     - Your steel defender gains a +2 bonus to Armor Class.
+    - Whenever your steel defender uses its Deflect Attack, the
+      attacker takes force damage equal to 1d4 +your Intelligence
+      modifier.
 
-    - Whenever your steel defender uses its Deflect Attack, the attacker takes
-      force damage equal to 1d4 +your Intelligence modifier.
     """
 
     name = "Improved Defender"
