@@ -26,23 +26,24 @@ class BardicInspiration(Feature):
     at 15th level.
 
     """
+
     _name = "Bardic Inspiration"
     source = "Bard"
 
     @property
     def name(self):
         level = self.owner.Bard.level
-        die = 'd6'
+        die = "d6"
         if level >= 5:
-            die = 'd8'
+            die = "d8"
         if level >= 10:
-            die = 'd10'
+            die = "d10"
         if level >= 15:
-            die = 'd12'
+            die = "d12"
         num = max(1, self.owner.charisma.modifier)
-        rest = 'LR'
+        rest = "LR"
         if level >= 5:  # font of inspiration
-            rest = 'SR'
+            rest = "SR"
         return self._name + " ({:d}{:s}/{:s})".format(num, die, rest)
 
 
@@ -52,6 +53,7 @@ class JackOfAllTrades(Feature):
     proficiency bonus. (Included in stats on Character Sheet above).
 
     """
+
     name = "Jack of All Trades"
     source = "Bard"
 
@@ -65,19 +67,20 @@ class SongOfRest(Feature):
     1d8 at 9th level, to 1d10 at 13th level, and to 1d12 at 17th level.
 
     """
+
     _name = "Song of Rest"
     source = "Bard"
 
     @property
     def name(self):
         level = self.owner.Bard.level
-        die = ' (1d6)'
+        die = " (1d6)"
         if level >= 9:
-            die = ' (1d8)'
+            die = " (1d8)"
         if level >= 13:
-            die = ' (1d10)'
+            die = " (1d10)"
         if level >= 17:
-            die = ' (1d12)'
+            die = " (1d12)"
         return self._name + die
 
 
@@ -90,6 +93,7 @@ class BardExpertise(Feature):
     Add these skills to "skill_expertise" in your character.py file
 
     """
+
     name = "Expertise"
     source = "Bard"
 
@@ -99,6 +103,7 @@ class FontOfInspiration(Feature):
     Bardic Inspiration when you finish a short or long rest.
 
     """
+
     name = "Font of Inspiration"
     source = "Bard"
 
@@ -114,6 +119,7 @@ class Countercharm(Feature):
     required).
 
     """
+
     name = "Countercharm"
     source = "Bard"
 
@@ -127,6 +133,7 @@ class MagicalSecrets(Feature):
     additional spells from any class at 14th level and again at 18th level.
 
     """
+
     name = "Magical Secrets"
     source = "Bard"
 
@@ -136,6 +143,7 @@ class SuperiorInspiration(Feature):
     Inspiration left, you regain one use.
 
     """
+
     name = "Superior Inspiration"
     source = "Bard"
 
@@ -146,6 +154,7 @@ class LoreProficiencies(Feature):
     three skills o f your choice.
 
     """
+
     name = "Bonus Proficiencies"
     source = "Bard (College of Lore)"
 
@@ -163,6 +172,7 @@ class CuttingWords(Feature):
     immune to being charmed.
 
     """
+
     name = "Cutting Words"
     source = "Bard (College of Lore)"
 
@@ -174,6 +184,7 @@ class AdditionalMagicalSecrets(Feature):
     against the number of bard spells you know.
 
     """
+
     name = "Additional Magical Secrets"
     source = "Bard (College of Lore)"
 
@@ -186,6 +197,7 @@ class PeerlessSkill(Feature):
     or fail
 
     """
+
     name = "Peerless Skill"
     source = "Bard (College of Lore)"
 
@@ -200,6 +212,7 @@ class CombatInspiration(Feature):
     attack, after seeing the roll but before knowing whether it hits or misses
 
     """
+
     name = "Combat Inspiration"
     source = "Bard (College of Valor)"
 
@@ -209,6 +222,7 @@ class BardExtraAttack(Feature):
     take the Attack action on your turn
 
     """
+
     name = "Extra Attack (x2)"
     source = "Bard (College of Valor)"
 
@@ -219,32 +233,35 @@ class BardBattleMagic(Feature):
     spell, you can make one weapon attack as a bonus action
 
     """
+
     name = "Battle Magic"
     source = "Bard (College of Valor)"
 
 
-# College of Glamour
+# XgtE - College of Glamour:
 class MantleOfInspiration(Feature):
-    """When you join the College of Glamour at 3rd level, you gain the ability to
-    weave a song of fey magic that imbues your allies with vigor and speed. As
-    a bonus action, you can expend one use of your Bardic Inspiration to grant
-    yourself a wondrous appearance. When you do so, choose a number of
-    creatures you can see and that can see you within 60 feet of you, up to a
-    number equal to your Charisma modifier (mini mum of one). Each of them
-    gains 5 temporary hit points. When a creature gains these temporary hit
-    points, it can immediately use its reaction to move up to its speed,
-    without provoking opportunity attacks. The number of temporary hit points
-    inoreases when you reach certain levels in this class, increasing to 8 at
-    5th level, 11 at 10th level, and 14 at 15th level.
+    """When you join the College of Glamour at 3rd level, you gain the
+    ability to weave a song of fey magic that imbues your allies with
+    vigor and speed. As a bonus action, you can expend one use of your
+    Bardic Inspiration to grant yourself a wondrous appearance. When
+    you do so, choose a number of creatures you can see and that can
+    see you within 60 feet of you, up to a number equal to your
+    Charisma modifier (minimum of one). Each of them gains 5 temporary
+    hit points. When a creature gains these temporary hit points, it
+    can immediately use its reaction to move up to its speed, without
+    provoking opportunity attacks. The number of temporary hit points
+    increases when you reach certain levels in this class, increasing
+    to 8 at 5th level, 11 at 10th level, and 14 at 15th level.
 
     """
+
     _name = "Mantle of Inspiration"
     source = "Bard (College of Glamour)"
 
     @property
     def name(self):
         level = self.owner.Bard.level
-        hp = 5 + 3*(level // 5)
+        hp = 5 + 3 * (level // 5)
         return self._name + " ({:d}HP)".format(hp)
 
 
@@ -267,6 +284,7 @@ class EnthrallingPerformance(Feature):
     you finish a short or long rest
 
     """
+
     name = "Enthralling Performance"
     source = "Bard (College of Glamour)"
 
@@ -284,6 +302,7 @@ class MantleOfMajesty(Feature):
     can't use it again until you finish a long rest
 
     """
+
     name = "Mantle of Majesty"
     source = "Bard (College of Glamour)"
 
@@ -304,6 +323,7 @@ class UnbreakableMajesty(Feature):
     you finish a short or long rest.
 
     """
+
     name = "Unbreakable Majesty"
     source = "Bard (College of Glamour)"
 
@@ -316,6 +336,7 @@ class SwordsProficiency(Feature):
     spells
 
     """
+
     name = "Bonus Proficiencies"
     source = "Bard (College of Swords)"
 
@@ -328,10 +349,13 @@ class BardFightingStyle(FeatureSelector):
 
     two-weapon fighting
     """
-    options = {'dueling': Dueling,
-               'two-weapon fighting': TwoWeaponFighting,
-               'two-weapon': TwoWeaponFighting,
-               'dual wield': TwoWeaponFighting}
+
+    options = {
+        "dueling": Dueling,
+        "two-weapon fighting": TwoWeaponFighting,
+        "two-weapon": TwoWeaponFighting,
+        "dual wield": TwoWeaponFighting,
+    }
     name = "Fighting Style (Select One)"
     source = "Bard (College of Swords)"
 
@@ -363,6 +387,7 @@ class BladeFlourish(Feature):
     target.
 
     """
+
     name = "Blade Flourish"
     source = "Bard (College of Swords)"
 
@@ -371,34 +396,37 @@ class MastersFlourish(Feature):
     """Starting at 14th level, whenever you use a Blade Flourish option, you can
     roll a d6 and use it instead of expend- ing a Bardic Inspiration die.
     """
+
     name = "Master's Flourish"
     source = "Bard (College of Swords)"
 
 
 # College of Whispers
 class PsychicBlades(Feature):
-    """When you join the College of Whispers at 3rd level, you gain the ability to
-    make your weapon attacks magically toxic to a creature's mind. When you hit
-    a creature with a weapon attack, you can expend one use ofyour Bardic
-    Inspiration to deal an extra 2d6 psychic damage to that target. You can do
-    so only once per round on your turn. The psychic damage increases when you
-    reach certain levels in this class, increasing to 3d6 at 5th level, 5d6
-    at 10th level, and 8d6 at 15th level.
+    """When you join the College of Whispers at 3rd level, you gain the
+    ability to make your weapon attacks magically toxic to a
+    creature's mind. When you hit a creature with a weapon attack, you
+    can expend one use ofyour Bardic Inspiration to deal an extra 2d6
+    psychic damage to that target. You can do so only once per round
+    on your turn. The psychic damage increases when you reach certain
+    levels in this class, increasing to 3d6 at 5th level, 5d6 at 10th
+    level, and 8d6 at 15th level.
 
     """
+
     _name = "Psychic Blades"
     source = "Bard (College of Whispers)"
 
     @property
     def name(self):
         level = self.owner.Bard.level
-        dice = ' (2d6)'
+        dice = " (2d6)"
         if level >= 5:
-            dice = ' (3d6)'
+            dice = " (3d6)"
         if level >= 10:
-            dice = ' (5d6)'
+            dice = " (5d6)"
         if level >= 15:
-            dice = ' (8d6)'
+            dice = " (8d6)"
         return self._name + dice
 
 
@@ -417,6 +445,7 @@ class WordsOfTerror(Feature):
     until you finish a short or long rest.
 
     """
+
     name = "Words of Terror"
     source = "Bard (College of Whispers)"
 
@@ -441,6 +470,7 @@ class MantleOfWhispers(Feature):
     until you finish a short or long rest.
 
     """
+
     name = "Mantle of Whispers"
     source = "Bard (College of Whispers)"
 
@@ -466,5 +496,6 @@ class ShadowLore(Feature):
     feature, you can't use it again until / you finish a long rest.
 
     """
+
     name = "Shadow Lore"
     source = "Bard (College of Whispers)"
