@@ -2,11 +2,13 @@ import os
 import subprocess
 import logging
 import warnings
+import io
 
 import pdfrw
 from fdfgen import forge_fdf
+from reportlab.pdfgen import canvas
 
-from dungeonsheets.stats import mod_str
+from dungeonsheets.forms import mod_str
 
 CHECKBOX_ON = "Yes"
 CHECKBOX_OFF = "Off"
@@ -57,7 +59,7 @@ def create_character_pdf_template(character, basename, flatten=False):
         "AC": str(character.armor_class),
         "Initiative": str(character.initiative),
         "Speed": str(character.speed),
-        "Passive": 10 + character.perception,
+        "Passive": character.passive_wisdom,
         # Saving throws (proficiencies handled later)
         "ST Strength": mod_str(character.strength.saving_throw),
         "ST Dexterity": mod_str(character.dexterity.saving_throw),
@@ -66,24 +68,24 @@ def create_character_pdf_template(character, basename, flatten=False):
         "ST Wisdom": mod_str(character.wisdom.saving_throw),
         "ST Charisma": mod_str(character.charisma.saving_throw),
         # Skills (proficiencies handled below)
-        "Acrobatics": mod_str(character.acrobatics),
-        "Animal": mod_str(character.animal_handling),
-        "Arcana": mod_str(character.arcana),
-        "Athletics": mod_str(character.athletics),
-        "Deception ": mod_str(character.deception),
-        "History ": mod_str(character.history),
-        "Insight": mod_str(character.insight),
-        "Intimidation": mod_str(character.intimidation),
-        "Investigation ": mod_str(character.investigation),
-        "Medicine": mod_str(character.medicine),
-        "Nature": mod_str(character.nature),
-        "Perception ": mod_str(character.perception),
-        "Performance": mod_str(character.performance),
-        "Persuasion": mod_str(character.persuasion),
-        "Religion": mod_str(character.religion),
-        "SleightofHand": mod_str(character.sleight_of_hand),
-        "Stealth ": mod_str(character.stealth),
-        "Survival": mod_str(character.survival),
+        "Acrobatics": mod_str(character.acrobatics.modifier),
+        "Animal": mod_str(character.animal_handling.modifier),
+        "Arcana": mod_str(character.arcana.modifier),
+        "Athletics": mod_str(character.athletics.modifier),
+        "Deception ": mod_str(character.deception.modifier),
+        "History ": mod_str(character.history.modifier),
+        "Insight": mod_str(character.insight.modifier),
+        "Intimidation": mod_str(character.intimidation.modifier),
+        "Investigation ": mod_str(character.investigation.modifier),
+        "Medicine": mod_str(character.medicine.modifier),
+        "Nature": mod_str(character.nature.modifier),
+        "Perception ": mod_str(character.perception.modifier),
+        "Performance": mod_str(character.performance.modifier),
+        "Persuasion": mod_str(character.persuasion.modifier),
+        "Religion": mod_str(character.religion.modifier),
+        "SleightofHand": mod_str(character.sleight_of_hand.modifier),
+        "Stealth ": mod_str(character.stealth.modifier),
+        "Survival": mod_str(character.survival.modifier),
         # Hit points
         "HDTotal": character.hit_dice,
         "HPMax": str(character.hp_max),
@@ -150,8 +152,6 @@ def create_character_pdf_template(character, basename, flatten=False):
         ("Wpn Name 2", "Wpn2 AtkBonus ", "Wpn2 Damage "),
         ("Wpn Name 3", "Wpn3 AtkBonus  ", "Wpn3 Damage "),
     ]
-    if len(character.weapons) == 0 or hasattr(character, "Monk"):
-        character.wield_weapon("unarmed")
     for _fields, weapon in zip(weapon_fields, character.weapons):
         name_field, atk_field, dmg_field = _fields
         fields[name_field] = weapon.name
@@ -160,7 +160,7 @@ def create_character_pdf_template(character, basename, flatten=False):
     # Additional attacks beyond 3
     attack = [
         f"{w.name}: Atk {w.attack_modifier:+d}, Dam {w.damage}/{w.damage_type}"
-        for w in character.weapons[len(weapon_fields):]
+        for w in character.weapons[len(weapon_fields) :]
     ]
     # Other attack information
     if character.armor:
@@ -177,10 +177,10 @@ def create_character_pdf_template(character, basename, flatten=False):
     # Prepare the actual PDF
     dirname = os.path.join(os.path.dirname(os.path.abspath(__file__)), "forms/")
     src_pdf = os.path.join(dirname, "blank-character-sheet-default.pdf")
-    return make_pdf(fields, src_pdf=src_pdf, basename=basename, flatten=flatten)
+    return make_pdf(fields, src_pdf=src_pdf, basename=basename, flatten=flatten, portrait="")
 
 
-def create_personality_pdf_template(character, basename, flatten=False):
+def create_personality_pdf_template(character, basename, portrait_file="", flatten=False):
     # Prepare the list of fields
     fields = {
         "CharacterName 2": character.name,
@@ -201,7 +201,7 @@ def create_personality_pdf_template(character, basename, flatten=False):
     # Prepare the actual PDF
     dirname = os.path.join(os.path.dirname(os.path.abspath(__file__)), "forms/")
     src_pdf = os.path.join(dirname, "blank-personality-sheet-default.pdf")
-    return make_pdf(fields, src_pdf=src_pdf, basename=basename, flatten=flatten)
+    return make_pdf(fields, src_pdf=src_pdf, basename=basename, flatten=flatten, portrait=portrait_file)
 
 
 def create_spells_pdf_template(character, basename, flatten=False):
@@ -486,10 +486,10 @@ def create_spells_pdf_template(character, basename, flatten=False):
     # Make the actual pdf
     dirname = os.path.join(os.path.dirname(os.path.abspath(__file__)), "forms/")
     src_pdf = os.path.join(dirname, "blank-spell-sheet-default.pdf")
-    make_pdf(fields, src_pdf=src_pdf, basename=basename, flatten=flatten)
+    make_pdf(fields, src_pdf=src_pdf, basename=basename, flatten=flatten, portrait="")
 
 
-def make_pdf(fields: dict, src_pdf: str, basename: str, flatten: bool = False):
+def make_pdf(fields: dict, src_pdf: str, basename: str, flatten: bool = False, portrait = ""):
     """Create a new PDF by applying fields to a src PDF document.
 
     Parameters
@@ -508,17 +508,17 @@ def make_pdf(fields: dict, src_pdf: str, basename: str, flatten: bool = False):
 
     """
     try:
-        _make_pdf_pdftk(fields, src_pdf, basename, flatten)
+        _make_pdf_pdftk(fields, src_pdf, basename, flatten, portrait)
     except FileNotFoundError:
         # pdftk could not run, so alert the user and use pdfrw
         warnings.warn(
             f"Could not run `{PDFTK_CMD}`, using fallback; forcing `--editable`.",
             RuntimeWarning,
         )
-        _make_pdf_pdfrw(fields, src_pdf, basename, flatten)
+        _make_pdf_pdfrw(fields, src_pdf, basename, flatten, portrait)
 
 
-def _make_pdf_pdfrw(fields: dict, src_pdf: str, basename: str, flatten: bool = False):
+def _make_pdf_pdfrw(fields: dict, src_pdf: str, basename: str, flatten: bool = False, portrait = ""):
     """Backup make_pdf function in case pdftk is not available."""
     template = pdfrw.PdfReader(src_pdf)
     # Different types of PDF fields
@@ -577,7 +577,7 @@ def _make_pdf_pdfrw(fields: dict, src_pdf: str, basename: str, flatten: bool = F
     pdfrw.PdfWriter().write(f"{basename}.pdf", template)
 
 
-def _make_pdf_pdftk(fields, src_pdf, basename, flatten=False):
+def _make_pdf_pdftk(fields, src_pdf, basename, flatten=False, portrait=""):
     """More robust way to make a PDF, but has a hard dependency."""
     # Create the actual FDF file
     fdfname = basename + ".fdf"
@@ -587,7 +587,12 @@ def _make_pdf_pdftk(fields, src_pdf, basename, flatten=False):
     fdf_file.write(fdf)
     fdf_file.close()
     # Build the final flattened PDF documents
-    dest_pdf = basename + ".pdf"
+    if portrait != "":
+        dest_pdf = basename + "-temp.pdf"
+        image_pdf = basename + "_image_tmp.pdf"
+        make_image_pdf(portrait, image_pdf)
+    else:
+        dest_pdf = basename + ".pdf"
     popenargs = [
         PDFTK_CMD,
         src_pdf,
@@ -599,5 +604,37 @@ def _make_pdf_pdftk(fields, src_pdf, basename, flatten=False):
     if flatten:
         popenargs.append("flatten")
     subprocess.call(popenargs)
+    # stamp with image
+    if portrait != "":
+        src_pdf = dest_pdf
+        stamped_pdf = basename + ".pdf"
+        popenargs = [
+            PDFTK_CMD,
+            src_pdf,
+            "stamp",
+            image_pdf,
+            "output",
+            stamped_pdf,
+        ]
+        popenargs.append("flatten")
+        subprocess.call(popenargs)
+        # Clean up
+        os.remove(image_pdf)
+        os.remove(dest_pdf)
     # Clean up temporary files
     os.remove(fdfname)
+
+def make_image_pdf(src_img:str, dest_pdf:str):
+    packet = io.BytesIO()
+    can = canvas.Canvas(packet)
+    x_start = 10
+    y_start = 240
+    can.drawImage(src_img, x_start, y_start, width=175, preserveAspectRatio=True, mask='auto')
+    can.showPage()
+    can.save()
+ 
+    #move to the beginning of the StringIO buffer
+    packet.seek(0)
+ 
+    new_pdf = pdfrw.PdfReader(packet)
+    pdfrw.PdfWriter().write(dest_pdf, new_pdf)
