@@ -55,6 +55,10 @@ def read_sheet_file(filename: Union[str, Path]) -> dict:
     # Remove imported dungeonsheets modules
     char_props.pop("import_homebrew", None)
     char_props.pop("mechanics", None)
+    # Remove private variables (start with a '_')
+    for attr in list(char_props.keys()):
+        if attr[0] == "_":
+            char_props.pop(attr)
     return char_props
 
 
@@ -280,7 +284,7 @@ class Roll20CharacterReader(JSONCharacterReader):
             match = prof_re.match(obj["name"])
             if match:
                 tool_profs.append(self.get_attrib(match.group(0)))
-        char_props["_proficiencies_text"] = tool_profs
+        char_props["proficiencies_text"] = tool_profs
         # Combat stats
         char_props["hp_max"] = self.as_int(self.get_attrib("hp", which="max"))
         # Equipment
@@ -526,11 +530,9 @@ class FoundryCharacterReader(JSONCharacterReader):
         tool_profs = [tool_labels[prof] for prof in tool_profs]
         custom_tool_profs = json_data["data"]["traits"]["toolProf"]["custom"]
         tool_profs.extend([s.strip() for s in custom_tool_profs.split(";")])
-        char_props["_proficiencies_text"] = tool_profs
+        char_props["proficiencies_text"] = tool_profs
         # Combat stats
-        char_props["hp_max"] = self.as_int(
-            json_data["data"]["attributes"]["hp"]["max"]
-        )
+        char_props["hp_max"] = self.as_int(json_data["data"]["attributes"]["hp"]["max"])
         # Equipment
         currency = json_data["data"]["currency"]
         char_props["cp"] = currency["cp"]
