@@ -11,39 +11,41 @@ class Bane(Spell):
     Levels: When you cast this spell using a spelslot of 2nd level or higher, you
     can target one aditional creature for each slot level above 1st.
     """
+
     name = "Bane"
     level = 1
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S', 'M')
-    materials = """A drop of blood"""
+    components = ("V", "S", "M")
+    materials = "A drop of blood"
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Bard', 'Cleric')
+    classes = ("Bard", "Cleric")
 
 
 class BanishingSmite(Spell):
     """The next time you hit a creature with a weapon attack before this spell ends,
     your weapon crackles with force, and the attack deals an extra 5d10 force damage
-     to the target. Additionally, if this attack reduces the target to 50 hit points
-     of fewer, you banish it. If the target is native to a different plane of
+    to the target. Additionally, if this attack reduces the target to 50 hit points
+    of fewer, you banish it. If the target is native to a different plane of
     existence than the on you're on, the target disappears, returning to its home
     plane. If the target is native to the plane you're on, the creature vanishes
     into a harmless demiplane. While there, the target is incapacitated. It remains
     there until the spell ends, at which point the target reappears in the space it
     left or in the nearest unoccupied space if that space is occupied.
     """
+
     name = "Banishing Smite"
     level = 5
     casting_time = "1 bonus action"
     casting_range = "Self"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Paladin',)
+    classes = ("Paladin",)
 
 
 class Banishment(Spell):
@@ -64,20 +66,21 @@ class Banishment(Spell):
     reappears in the space it left or in the nearest unoccupied space if that space
     is occupied. Otherwise, the target doesn't return.
 
-    At Higher Levels: When you
+    **At Higher Levels:** When you
     cast this spell using a spell slot of 5th level or higher, you can target one
     additional creature for each slot level above 4th.
     """
+
     name = "Banishment"
     level = 4
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S', 'M')
-    materials = """An item distasteful to the target"""
+    components = ("V", "S", "M")
+    materials = "An item distasteful to the target"
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric', 'Paladin', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Cleric", "Paladin", "Sorcerer", "Warlock", "Wizard")
 
 
 class Barkskin(Spell):
@@ -85,16 +88,17 @@ class Barkskin(Spell):
     rough, bark-like appearance, and the target's AC can't be less than 16,
     regardless of what kind of armor it is wearing.
     """
+
     name = "Barkskin"
     level = 2
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A handful of oak bark"""
+    components = ("V", "S", "M")
+    materials = "A handful of oak bark"
     duration = "Concentration, up to 1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Druid', 'Ranger')
+    classes = ("Druid", "Ranger")
 
 
 class BeaconOfHope(Spell):
@@ -103,40 +107,42 @@ class BeaconOfHope(Spell):
     death saving throws, and regains the maximum number of hit points possible from
     any healing.
     """
+
     name = "Beacon Of Hope"
     level = 3
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric',)
+    classes = ("Cleric",)
 
 
 class BeastBond(Spell):
     """You establish a telepathic link with one beast you touch that is
-     friendly to you or charmed by you. The spell fails if the beast's
-     Intelligence is 4 or higher.  Until the spell ends, the link is
-     active while you and the beast are within line of sight of each
-     other. Through the link, the beast can understand your telepathic
-     messages to it, and it can telepathically communicate simple
-     emotions and concepts back to you. While the link is active, the
-     beast gains advantage on attack rolls against any creature within
-     5 feet of you that you can see.
+    friendly to you or charmed by you. The spell fails if the beast's
+    Intelligence is 4 or higher.  Until the spell ends, the link is
+    active while you and the beast are within line of sight of each
+    other. Through the link, the beast can understand your telepathic
+    messages to it, and it can telepathically communicate simple
+    emotions and concepts back to you. While the link is active, the
+    beast gains advantage on attack rolls against any creature within
+    5 feet of you that you can see.
 
     """
+
     name = "Beast Bond"
     level = 1
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A bit of fur wrapped in a cloth"""
+    components = ("V", "S", "M")
+    materials = "A bit of fur wrapped in a cloth"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Divination"
-    classes = ('Druid', 'Ranger')
+    classes = ("Druid", "Ranger")
 
 
 class BeastSense(Spell):
@@ -146,28 +152,29 @@ class BeastSense(Spell):
     to your normal senses.
 
     """
+
     name = "Beast Sense"
     level = 2
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('S',)
-    materials = """"""
+    components = ("S",)
+    materials = ""
     duration = "Concentration, up to 1 hour"
     ritual = True
     magic_school = "Divination"
-    classes = ('Druid', 'Ranger')
+    classes = ("Druid", "Ranger")
 
 
 class BestowCurse(Spell):
     """You touch a creature, and that creature must succeed on a Wisdom saving throw or
-     become cursed for the duration of the spell. When you cast this spell, choose
+    become cursed for the duration of the spell. When you cast this spell, choose
     the nature of the curse from the following options:* Choose one ability score.
     While cursed, the target has disadvantage on ability checks and saving throws
     made with that ability score.* While cursed, the target has disadvantage on
     attack rolls against you.* While cursed, the target must make a Wisdom saving
     throw at the start of each of its turns. If it fails, it wastes its action that
     turn doing nothing.* While the target is cursed, your attacks and spells deal an
-     extra 1d8 necrotic damage to the target.
+    extra 1d8 necrotic damage to the target.
 
     A remove curse spell ends this
     effect. At the DM's option, you may choose an alternative curse effect, but it
@@ -175,7 +182,7 @@ class BestowCurse(Spell):
     The DM has final say on
     such a curse's effect.
 
-    At Higher Levels: If you cast this spell using a spell
+    **At Higher Levels:** If you cast this spell using a spell
     slot of 4th level or higher, the duration is concentration, up to 10 minutes.
 
     If you use a spell slot of 5th level or higher, the duration is 8 hours.
@@ -187,16 +194,17 @@ class BestowCurse(Spell):
     spell slot of 5th level or higher grants a duration that doesn't require
     concentration.
     """
+
     name = "Bestow Curse"
     level = 3
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Bard', 'Cleric', 'Wizard')
+    classes = ("Bard", "Cleric", "Wizard")
 
 
 class BigbysHand(Spell):
@@ -254,41 +262,43 @@ class BigbysHand(Spell):
     by 2d6 for each slot level above 5th.
 
     """
+
     name = "Bigbys Hand"
     level = 5
     casting_time = "1 action"
     casting_range = "120 feet"
-    components = ('V', 'S', 'M')
-    materials = """An eggshell and a snakeskin glove"""
+    components = ("V", "S", "M")
+    materials = "An eggshell and a snakeskin glove"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class BladeBarrier(Spell):
     """You create a vertical wall of whirling, razor-sharp blades made of magical
     energy. The wall appears within range and lasts for the duration. You can make a
-     straight wall up to 100 feet long, 20 feet high, and 5 feet thick, or a ringed
+    straight wall up to 100 feet long, 20 feet high, and 5 feet thick, or a ringed
     wall up to 60 feet in diameter, 20 feet high, and 5 feet thick. The wall
     provides three-quarters cover to creatures behind it, and its space is difficult
-     terrain.
+    terrain.
 
      When a creature enters the wall's area for the first time on a turn
-     or starts its turn there, the creature must make a Dexterity saving throw. On a
-     failed save, the creature takes 6 d10 slashing damage. On a successful save,
+    or starts its turn there, the creature must make a Dexterity saving throw. On a
+    failed save, the creature takes 6 d10 slashing damage. On a successful save,
     the creature takes half as much damage.
     """
+
     name = "Blade Barrier"
     level = 6
     casting_time = "1 action"
     casting_range = "90 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 10 minutes"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Cleric',)
+    classes = ("Cleric",)
 
 
 class BladeWard(Spell):
@@ -296,16 +306,17 @@ class BladeWard(Spell):
     your next turn, you have resistance against bludgeoning, piercing, and slashing
     damage dealt by weapon attacks.
     """
+
     name = "Blade Ward"
     level = 0
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "1 round"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Bard', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Bard", "Sorcerer", "Warlock", "Wizard")
 
 
 class Bless(Spell):
@@ -317,21 +328,22 @@ class Bless(Spell):
     Higher Levels: When you cast this spell using a spell slot of 2nd level or
     higher, you can target one additional creature for each slot level above 1st.
     """
+
     name = "Bless"
     level = 1
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S', 'M')
-    materials = """A sprinkling of holy water"""
+    components = ("V", "S", "M")
+    materials = "A sprinkling of holy water"
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Cleric', 'Paladin')
+    classes = ("Cleric", "Paladin")
 
 
 class Blight(Spell):
     """Necromantic energy washes over a creature of your choice that you can see within
-     range, draining moisture and vitality from it. The target must make a
+    range, draining moisture and vitality from it. The target must make a
     Constitution saving throw. The target takes 8d8 necrotic damage on a failed
     save, or half as much damage on a successful one. This spell has no effect on
     undead or constructs.
@@ -347,16 +359,17 @@ class Blight(Spell):
     Levels: When you cast this spell using a spell slot of 5th level or higher, the
     damage increases by 1d8 for each slot level above 4th.
     """
+
     name = "Blight"
     level = 4
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Druid', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Druid", "Sorcerer", "Warlock", "Wizard")
 
 
 class BlindingSmite(Spell):
@@ -371,16 +384,17 @@ class BlindingSmite(Spell):
     no longer blinded.
 
     """
+
     name = "Blinding Smite"
     level = 3
     casting_time = "1 bonus action"
     casting_range = "Self"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Paladin',)
+    classes = ("Paladin",)
 
 
 class BlindnessDeafness(Spell):
@@ -390,30 +404,31 @@ class BlindnessDeafness(Spell):
     duration. At the end of each of its turns, the target can make a
     Constitution saving throw. On a success, the spell ends.
 
-    At Higher Levels: When you cast this spell using a spell slot of
+    **At Higher Levels:** When you cast this spell using a spell slot of
     3rd level or higher, you can target one additional creature for
     each slot level above 2nd.
 
     """
+
     name = "Blindness/Deafness"
     level = 2
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V',)
+    components = ("V",)
     duration = "1 minute"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Bard', 'Cleric', 'Sorcerer', 'Wizard')
+    classes = ("Bard", "Cleric", "Sorcerer", "Wizard")
 
 
 class Blink(Spell):
     """Roll a d20 at the end of each of your turns for the duration of the spell. On a
     roll of 11 or higher, you vanish from your current plane of existence and appear
-     in the Etheral Plane (the spell fails and the casting is wasted if you were
+    in the Etheral Plane (the spell fails and the casting is wasted if you were
     already on that plane).
 
     At the start of you next turn, and when the spell ends
-     if you are on the Etheral Plane, you return to an unoccupied space of your
+    if you are on the Etheral Plane, you return to an unoccupied space of your
     choice that you can see within 10 feet of the space you vanished from. If no
     unoccupied space is available within that rang, you appear in the nearest
     unoccupied space (chosen at random if more that one space is equally near). You
@@ -421,38 +436,40 @@ class Blink(Spell):
 
     While on the Ethereal Plane, you can see
     and hear the plane you originated from, which is cast in shades of gray, and you
-     can't see anything more than 60 feet away.You can only affect and be affected
+    can't see anything more than 60 feet away.You can only affect and be affected
     by other reatures on the Ethereal Plane. Creature that aren't there can't
     perceive you or interact with you, unless they have the ability to do so.
     """
+
     name = "Blink"
     level = 3
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "1 minute"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class Blur(Spell):
     """Your body becomes blurred, shifting and wavering to all who can see you. For the
-     duration, any creature has disadvantage on attack rolls against you. An
+    duration, any creature has disadvantage on attack rolls against you. An
     attacker is immune to this effect if it doesnt rely on sight, as with
     blindsight, or can see through illusions, as with truesight.
     """
+
     name = "Blur"
     level = 2
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Illusion"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class BonesOfTheEarth(Spell):
@@ -484,20 +501,21 @@ class BonesOfTheEarth(Spell):
     each slot level above 6th.
 
     """
+
     name = "Bones Of The Earth"
     level = 6
     casting_time = "1 action"
     casting_range = "120 feet"
-    components = ('V', 'S')
+    components = ("V", "S")
     duration = "Instantaneous"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Druid',)
+    classes = ("Druid",)
 
 
 class BoomingBlade(Spell):
     """As part of the action used to cast this spell, you must make a melee attack with
-     a weapon against one creature within the spell's range, otherwise the spell
+    a weapon against one creature within the spell's range, otherwise the spell
     fails.
     On a hit, the target suffers the attack's normal effects, and it becomes
     sheathed in booming energy until the start of your next turn. If the target
@@ -508,18 +526,19 @@ class BoomingBlade(Spell):
     At
     Higher Levels: At 5th level, the melee attack deals an extra 1d8 thunder damage
     to the target, and the damage the target takes for moving increases to 2d8. Both
-     damage rolls increase by 1d8 at 11th level and 17th level.
+    damage rolls increase by 1d8 at 11th level and 17th level.
     """
+
     name = "Booming Blade"
     level = 0
     casting_time = "1 action"
     casting_range = "5 feet"
-    components = ('V', 'M')
-    materials = """A weapon"""
+    components = ("V", "M")
+    materials = "A weapon"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Sorcerer", "Warlock", "Wizard")
 
 
 class BrandingSmite(Spell):
@@ -529,20 +548,21 @@ class BrandingSmite(Spell):
     the target sheds dim light in a 5-foot radius and can't become invisible until
     the spell ends.
 
-    At Higher Levels: When you cast this spell using a spell slot
+    **At Higher Levels:** When you cast this spell using a spell slot
     of 3rd level or higher, the extra damage increases by 1d6 for each slot level
     above 2nd.
     """
+
     name = "Branding Smite"
     level = 2
     casting_time = "1 bonus action"
     casting_range = "Self"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Paladin',)
+    classes = ("Paladin",)
 
 
 class BurningHands(Spell):
@@ -555,16 +575,17 @@ class BurningHands(Spell):
     ignites any flammable objects in the area that aren't being worn or carried.
 
     At
-     Higher Levels: When you cast this spell using a spell slot of 2nd level or
+    Higher Levels: When you cast this spell using a spell slot of 2nd level or
     higher, the damage increases by 1d6 for each slot level above 1st.
     """
+
     name = "Burning Hands"
     level = 1
     casting_time = "1 action"
     casting_range = "Self (15-foot cone)"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
