@@ -5,13 +5,13 @@ class OtilukesFreezingSphere(Spell):
     """A frigid globe of cold energy streaks from your fingertips to a point of your
     choice within range, where it explodes in a 60-foot-radius sphere.
     Each creature
-     within the area must make a Constitution saving throw. On a failed save, a
+    within the area must make a Constitution saving throw. On a failed save, a
     creature takes 10d6 cold damage. On a successful save, it takes half as much
     damage.
 
     If the globe strikes a body of water or a liquid that is principally
     water (not including water-based creatures), it freezes the liquid to a depth of
-     6 inches over an area 30 feet square. This ice lasts for 1 minute. Creatures
+    6 inches over an area 30 feet square. This ice lasts for 1 minute. Creatures
     that were swimming on the surface of frozen water are trapped in the ice. A
     trapped creature can use an action to make a Strength check against your spell
     save DC to break free.
@@ -20,7 +20,7 @@ class OtilukesFreezingSphere(Spell):
     the spell, if you wish. A small globe about the size of a sling stone, cool to
     the touch, appears in your hand. At any time, you or a creature you give the
     globe to can throw the globe (to a range of 40 feet) or hurl it with a sling (to
-     the sling's normal range). It shatters on impact, with the same effect as the
+    the sling's normal range). It shatters on impact, with the same effect as the
     normal casting of the spell. You can also set the globe down without shattering
     it. After 1 minute, if the globe hasn't already shattered, it explodes.
 
@@ -28,16 +28,17 @@ class OtilukesFreezingSphere(Spell):
     Higher Levels: When you cast this spell using a spell slot of 7th level or
     higher, the damage increases by 1d6 for each slot level above 6th
     """
+
     name = "Otilukes Freezing Sphere"
     level = 6
     casting_time = "1 action"
     casting_range = "300 feet"
-    components = ('V', 'S', 'M')
-    materials = """A small crystal sphere"""
+    components = ("V", "S", "M")
+    materials = "A small crystal sphere"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class OtilukesResilientSphere(Spell):
@@ -47,7 +48,7 @@ class OtilukesResilientSphere(Spell):
 
     Nothing---not
     physical objects, energy, or other spell effects---can pass through the barrier,
-     in or out, though a creature in the sphere can breathe there. The sphere is
+    in or out, though a creature in the sphere can breathe there. The sphere is
     immune to all damage, and a creature or object inside can't be damaged by
     attacks or effects originating from outside, nor can a creature inside the
     sphere damage anything outside it.
@@ -61,16 +62,20 @@ class OtilukesResilientSphere(Spell):
     A disintegrate spell targeting the globe destroys it without
     harming anything inside it.
     """
+
     name = "Otilukes Resilient Sphere"
     level = 4
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S', 'M')
-    materials = """A hemispherical piece of clear crystal and a matching hemispherical piece of gum arabic"""
+    components = ("V", "S", "M")
+    materials = (
+        "A hemispherical piece of clear crystal and a matching hemispherical piece of"
+        " gum arabic"
+    )
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class OttosIrresistibleDance(Spell):
@@ -85,15 +90,14 @@ class OttosIrresistibleDance(Spell):
     it. As an action, a dancing creature makes a Wisdom saving throw to regain
     control of itself. On a successful save, the spell ends.
     """
+
     name = "Ottos Irresistible Dance"
     level = 6
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Bard', 'Wizard')
-
-
+    classes = ("Bard", "Wizard")
