@@ -3,22 +3,23 @@ from dungeonsheets.spells.spells import Spell
 
 class PassWithoutTrace(Spell):
     """A veil of shadows and silence radiates from you, masking you and your companions
-     from detection.
+    from detection.
     For the duration, each creature you choose within 30 feet of
     you (including you) has a +10 bonus to Dexterity (Stealth) checks and can't be
     tracked except by magical means. A creature that receives this bonus leaves
     behind no tracks or other traces of its passage.
     """
+
     name = "Pass Without Trace"
     level = 2
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S', 'M')
-    materials = """Ashes from a burned leaf of mistletoe and a sprig of spruce"""
+    components = ("V", "S", "M")
+    materials = "Ashes from a burned leaf of mistletoe and a sprig of spruce"
     duration = "Concentration, up to 1 hour"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Druid', 'Ranger')
+    classes = ("Druid", "Ranger")
 
 
 class Passwall(Spell):
@@ -29,19 +30,20 @@ class Passwall(Spell):
     structure surrounding it.
 
     When the opening disappears, any creatures or objects
-     still in the passage created by the spell are safely ejected to an unoccupied
+    still in the passage created by the spell are safely ejected to an unoccupied
     space nearest to the surface on which you cast the spell.
     """
+
     name = "Passwall"
     level = 5
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S', 'M')
-    materials = """A pinch of sesame seeds"""
+    components = ("V", "S", "M")
+    materials = "A pinch of sesame seeds"
     duration = "1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class PhantasmalForce(Spell):
@@ -52,15 +54,15 @@ class PhantasmalForce(Spell):
     choice that is no larger than a 10-foot cube and that is
     perceivable only to the target for the duration. This spell has no
     effect on undead or constructs.
-    
+
     The phantasm includes sound, temperature, and other stimuli, also
     evident only to the creature.
-    
+
     The target can use its action to examine the phantasm with an
     Intelligence (Investigation) check against your spell save DC. If
     the check succeeds, the target realizes that the phantasm is an
     illusion, and the spell ends.
-    
+
     While a target is affected by the spell, the target treats the
     phantasm as if it were real. The target rationalizes any illogical
     outcomes from interacting with the phantasm. For example, a target
@@ -69,7 +71,7 @@ class PhantasmalForce(Spell):
     fall, it still believes that the bridge exists and comes up with
     some other explanation for its fall - it was pushed, it slipped,
     or a strong wind might have knocked it off.
-    
+
     An affected target is so convinced of the phantasm's reality that
     it can even take damage from the illusion. A phantasm created to
     appear as a creature can attack the target. Similarly, a phantasm
@@ -80,43 +82,46 @@ class PhantasmalForce(Spell):
     or hazard that could logically deal damage, such as by
     attacking. The target perceives the damage as a type appropriate
     to the illusion.
-    
+
     """
+
     name = "Phantasmal Force"
     level = 2
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S', 'M')
-    materials = """A bit of fleece"""
+    components = ("V", "S", "M")
+    materials = "A bit of fleece"
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Illusion"
-    classes = ('Bard', 'Sorcerer', 'Wizard')
+    classes = ("Bard", "Sorcerer", "Wizard")
 
 
 class PhantasmalKiller(Spell):
-    """You tap into the nightmares of a creature you can see within range and create an
-     illusory manifestation of its deepest fears, visible only to that creature.
-    The
-     target must make a Wisdom saving throw. On a failed save, the target becomes
-    frightened for the duration. At the end of each of the target's turns before the
-     spell ends, the target must succeed on a Wisdom saving throw or take 4d10
-    psychic damage. On a successful save, the spell ends.
+    """You tap into the nightmares of a creature you can see within range
+    and create an illusory manifestation of its deepest fears, visible
+    only to that creature.  The target must make a Wisdom saving
+    throw. On a failed save, the target becomes frightened for the
+    duration. At the end of each of the target's turns before the
+    spell ends, the target must succeed on a Wisdom saving throw or
+    take 4d10 psychic damage. On a successful save, the spell ends.
+
+    **At Higher Levels:** When you cast this spell using a spell slot
+    of 5th level or higher, the damage increases by 1d10 for each slot
+    level above 4th.
 
-    At Higher Levels: When
-    you cast this spell using a spell slot of 5th level or higher, the damage
-    increases by 1d1O for each slot level above 4th.
     """
+
     name = "Phantasmal Killer"
     level = 4
     casting_time = "1 action"
     casting_range = "120 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Illusion"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class PhantomSteed(Spell):
@@ -133,16 +138,17 @@ class PhantomSteed(Spell):
     dismount. The spell ends if you use an action to dismiss it or if the steed
     takes any damage.
     """
+
     name = "Phantom Steed"
     level = 3
     casting_time = "1 minute"
     casting_range = "30 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "1 hour"
     ritual = True
     magic_school = "Illusion"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class PlanarAlly(Spell):
@@ -187,16 +193,17 @@ class PlanarAlly(Spell):
     A creature enlisted to join your group counts as a member of it, receiving a
     full share of experience points awarded.
     """
+
     name = "Planar Ally"
     level = 6
     casting_time = "10 minutes"
     casting_range = "60 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Conjuration"
-    classes = ('Cleric',)
+    classes = ("Cleric",)
 
 
 class PlanarBinding(Spell):
@@ -208,7 +215,7 @@ class PlanarBinding(Spell):
     the completion of the casting, the target must make a Charisma saving throw. On
     a failed save, it is bound to serve you for the duration. If the creature w as
     summoned or created by another spell, that spell's duration is extended to match
-     the duration of this spell.
+    the duration of this spell.
 
     A bound creature must follow your instructions to
     the best of its ability. You might command the creature to accompany you on an
@@ -218,40 +225,41 @@ class PlanarBinding(Spell):
     your instructions completely before the spell ends, it travels to you to report
     this fact if you are on the same plane of existence. If you are on a different
     plane of existence, it returns to the place where you bound it and remains there
-     until the spell ends.
+    until the spell ends.
 
-    At Higher Levels: When you cast this spell using a spell
-     slot of a higher level, the duration increases to:
+    **At Higher Levels:** When you cast this spell using a spell
+    slot of a higher level, the duration increases to:
     10 days with a 6th-level
     slot,
     30 days with a 7th-level slot,
     180 days with an 8th-level slot,
     1 year
-     and 1 day with a 9th-level spell slot.
+    and 1 day with a 9th-level spell slot.
     """
+
     name = "Planar Binding"
     level = 5
     casting_time = "1 hour"
     casting_range = "60 feet"
-    components = ('V', 'S', 'M')
-    materials = """A jewel worth at least 1,000 gp, which the spell consumes"""
+    components = ("V", "S", "M")
+    materials = "A jewel worth at least 1,000 gp, which the spell consumes"
     duration = "24 hours"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Bard', 'Cleric', 'Druid', 'Wizard')
+    classes = ("Bard", "Cleric", "Druid", "Wizard")
 
 
 class PlaneShift(Spell):
     """You and up to eight willing creatures who link hands in a circle are transported
-     to a different plane of existence. You can specify a target destination in
+    to a different plane of existence. You can specify a target destination in
     general terms, such as the City of Brass on the Elemental Plane of Fire or the
     palace of Dispater on the second level of the Nine Hells, and you appear in or
     near that destination. If you are trying to reac the City of Brass, for example,
-     you might arrive in its Street of Steel, before its Gate of Ashes, or looking
+    you might arrive in its Street of Steel, before its Gate of Ashes, or looking
     at the city from across the Sea of Fire, at the DM's discretion.
 
     Alternatively,
-     if you know the sigil sequence of a teleportation circle on another plane of
+    if you know the sigil sequence of a teleportation circle on another plane of
     existence, this spell can take you to that circle. If the teleportation circle
     is too small to hold all the creatures you transported, they appear in the
     closest unoccupied spaces next to the circle.
@@ -261,18 +269,22 @@ class PlaneShift(Spell):
     make a melee spell attack against it. On a hit, the creature must make a
     Charisma saving throw. If the creature fails the save, it is transported to a
     random location on the plane of existence you specify. A creature so transported
-     must find its own way back to your current plane of existence.
+    must find its own way back to your current plane of existence.
     """
+
     name = "Plane Shift"
     level = 7
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A forked, metal rod worth at least 250 gp, attuned to a particular plane of existence"""
+    components = ("V", "S", "M")
+    materials = (
+        "A forked, metal rod worth at least 250 gp, attuned to a particular plane of"
+        " existence"
+    )
     duration = "Instantaneous"
     ritual = False
     magic_school = "Conjuration"
-    classes = ('Cleric', 'Druid', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Cleric", "Druid", "Sorcerer", "Warlock", "Wizard")
 
 
 class PlantGrowth(Spell):
@@ -282,8 +294,8 @@ class PlantGrowth(Spell):
 
     If you cast this spell using 1 action, choose a point within range. All normal
     plants in a 100-foot radius centered on that point become thick and overgrown. A
-     creature moving through the area must spend 4 feet of movement for every 1 foot
-     it moves.
+    creature moving through the area must spend 4 feet of movement for every 1 foot
+    it moves.
 
     You can exclude one or more areas of any size within the spell's
     area from being affected.
@@ -293,16 +305,17 @@ class PlantGrowth(Spell):
     enriched for 1 year. The plants yield twice the normal amount of food when
     harvested.
     """
+
     name = "Plant Growth"
     level = 3
     casting_time = "Special"
     casting_range = "150 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Bard', 'Druid', 'Ranger')
+    classes = ("Bard", "Druid", "Ranger")
 
 
 class PoisonSpray(Spell):
@@ -310,20 +323,21 @@ class PoisonSpray(Spell):
     puff of noxious gas from your palm. The creature must succeed on a Constitution
     saving throw or take 1d12 poison damage.
 
-    At Higher Levels: This spell's damage
+    **At Higher Levels:** This spell's damage
     increases by 1d12 when you reach 5th level (2d12), 11th level (3d12), 17th level
-     (4d12).
+    (4d12).
     """
+
     name = "Poison Spray"
     level = 0
     casting_time = "1 action"
     casting_range = "10 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Conjuration"
-    classes = ('Druid', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Druid", "Sorcerer", "Warlock", "Wizard")
 
 
 class Polymorph(Spell):
@@ -347,23 +361,24 @@ class Polymorph(Spell):
 
 
     The creature is limited in the actions it can perform by the nature of its new
-     form, and it can't speak, cast spells, or take any other action that requires
+    form, and it can't speak, cast spells, or take any other action that requires
     hands or speech.
 
     The target's gear melds into the new form. The creature can't
     activate, use, wield, or otherwise benefit from any of its equipment. This spell
-     can't affect a target that has 0 hit points.
+    can't affect a target that has 0 hit points.
     """
+
     name = "Polymorph"
     level = 4
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S', 'M')
-    materials = """A caterpillar cocoon"""
+    components = ("V", "S", "M")
+    materials = "A caterpillar cocoon"
     duration = "Concentration, up to 1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Bard', 'Druid', 'Sorcerer', 'Wizard')
+    classes = ("Bard", "Druid", "Sorcerer", "Wizard")
 
 
 class PowerWordHeal(Spell):
@@ -372,16 +387,17 @@ class PowerWordHeal(Spell):
     stunned, the condition ends. If the creature is prone, it can use its reaction
     to stand up. This spell has no effect on undead or constructs.
     """
+
     name = "Power Word Heal"
     level = 9
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Bard',)
+    classes = ("Bard",)
 
 
 class PowerWordKill(Spell):
@@ -389,43 +405,45 @@ class PowerWordKill(Spell):
     to die instantly. If the creature you chose has 100 hit points or fewer, it
     dies. Otherwise, the spell has no effect.
     """
+
     name = "Power Word Kill"
     level = 9
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Bard', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Bard", "Sorcerer", "Warlock", "Wizard")
 
 
 class PowerWordPain(Spell):
     """You speak a word of power that causes waves of intense pain to assail one
     creature you can see within range. If the target has 100 hit points or fewer, it
-     is subject to crippling pain. Otherwise, the spell has no effect on it. A
+    is subject to crippling pain. Otherwise, the spell has no effect on it. A
     target is also unaffected if it is immune to being charmed.
     While the target is
     affected by crippling pain, any speed it has can be no higher than 10 feet. The
     target also has disadvantage on attack rolls, ability checks, and saving throws,
-     other than Constitution saving throws. Finally, if the target tries to cast a
+    other than Constitution saving throws. Finally, if the target tries to cast a
     spell, it must first succeed on a Constitution saving throw, or the casting
     fails and the spell is wasted.
     A target suffering this pain can make a
     Constitution saving throw at the end of each of its turns. On a successful save,
-     the pain ends.
+    the pain ends.
     """
+
     name = "Power Word Pain"
     level = 7
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Sorcerer", "Warlock", "Wizard")
 
 
 class PowerWordStun(Spell):
@@ -435,37 +453,39 @@ class PowerWordStun(Spell):
     must make a Constitution saving throw at the end of each of its turns. On a
     successful save, this stunning effect ends.
     """
+
     name = "Power Word Stun"
     level = 8
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Bard', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Bard", "Sorcerer", "Warlock", "Wizard")
 
 
 class PrayerOfHealing(Spell):
     """Up to six creatures of your choice that you can see within range each regain hit
-     points equal to 2d8 + your spellcasting ability modifier. This spell has no
+    points equal to 2d8 + your spellcasting ability modifier. This spell has no
     effect on undead or constructs.
 
-    At Higher Levels: When you cast this spell
+    **At Higher Levels:** When you cast this spell
     using a spell slot of 3rd level or higher, the healing increases by 1d8 for each
-     slot level above 2nd.
+    slot level above 2nd.
     """
+
     name = "Prayer Of Healing"
     level = 2
     casting_time = "10 minutes"
     casting_range = "30 feet"
-    components = ('V',)
-    materials = """"""
+    components = ("V",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Cleric',)
+    classes = ("Cleric",)
 
 
 class Prestidigitation(Spell):
@@ -484,41 +504,43 @@ class Prestidigitation(Spell):
     or a symbol appear on an object or a surface for 1 hour.
     -You create a
     nonmagical trinket or an illusory image that can fit in your hand and that lasts
-     until the end of your next turn.
+    until the end of your next turn.
     If you cast this spell multiple times, you
     can have up to three of its non-instantaneous effects active at a time, and you
     can dismiss such an effect as an action.
     """
+
     name = "Prestidigitation"
     level = 0
     casting_time = "1 action"
     casting_range = "10 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Up to 1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Bard', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Bard", "Sorcerer", "Warlock", "Wizard")
 
 
 class PrimalSavagery(Spell):
     """You channel primal magic to cause your teeth or fingernails to sharpen, ready to
-     deliver a corrosive attack. Make a melee spell attack against one creature
+    deliver a corrosive attack. Make a melee spell attack against one creature
     within 5 feet of you. On a hit, the target takes 1d10 acid damage. After you
     make the attack, your teeth or fingernails return to normal. The spell's damage
     increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th
     level (4d10).
     """
+
     name = "Primal Savagery"
     level = 0
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('S',)
-    materials = """"""
+    components = ("S",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Druid',)
+    classes = ("Druid",)
 
 
 class PrimordialWard(Spell):
@@ -530,16 +552,17 @@ class PrimordialWard(Spell):
     triggering damage. If you do so, the resistances end, and you have the immunity
     until the end of your next turn, at which time the spell ends.
     """
+
     name = "Primordial Ward"
     level = 6
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Druid',)
+    classes = ("Druid",)
 
 
 class PrismaticSpray(Spell):
@@ -559,7 +582,7 @@ class PrismaticSpray(Spell):
     half as much damage on a successful one.
 
     4. Green. The target takes 10d6 poison
-     damage on a failed save, or half as much damage on a successful one.
+    damage on a failed save, or half as much damage on a successful one.
 
     5. Blue.
     The target takes 10d6 cold damage on a failed save, or half as much damage on a
@@ -573,9 +596,9 @@ class PrismaticSpray(Spell):
     of both until the target collects three of a kind.
 
     7. Violet. On a failed save,
-     the target is blinded. It must then make a Wisdom saving throw at the start of
+    the target is blinded. It must then make a Wisdom saving throw at the start of
     your next turn. A successful save ends the blindness. If it fails that save, the
-     creature is transported to another plane of existence of the DM's choosing and
+    creature is transported to another plane of existence of the DM's choosing and
     is no longer blinded. (Typically, a creature that is on a plane that isn't its
     home plane is banished home, while other creatures are usually cast into the
     Astral or Ethereal planes.)
@@ -583,16 +606,17 @@ class PrismaticSpray(Spell):
     8. Special. The target is struck by two rays. Roll
     twice more, rerolling any 8.
     """
+
     name = "Prismatic Spray"
     level = 7
     casting_time = "1 action"
     casting_range = "Self (60-foot cone)"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class PrismaticWall(Spell):
@@ -671,16 +695,17 @@ class PrismaticWall(Spell):
     higher level that can end spells and magical effects.
 
     """
+
     name = "Prismatic Wall"
     level = 9
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "10 minutes"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class ProduceFlame(Spell):
@@ -696,19 +721,20 @@ class ProduceFlame(Spell):
     you. Make a ranged spell attack. On a hit, the target takes 1d8 fire damage.
 
     At
-     Higher Levels: This spell's damage increases by 1d8 when you reach 5th level
+    Higher Levels: This spell's damage increases by 1d8 when you reach 5th level
     (2d8), 11th level (3d8), and 17th level (4d8).
     """
+
     name = "Produce Flame"
     level = 0
     casting_time = "1 action"
     casting_range = "Self"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "10 minutes"
     ritual = False
     magic_school = "Conjuration"
-    classes = ('Druid',)
+    classes = ("Druid",)
 
 
 class ProgrammedIllusion(Spell):
@@ -722,14 +748,14 @@ class ProgrammedIllusion(Spell):
     condition you specify occurs, the illusion springs into existence and performs
     in the manner you described. Once the illusion finishes performing, it
     disappears and remains dormant for 10 minutes. After this time, the illusion can
-     be activated again.
+    be activated again.
 
     The triggering condition can be as general or as detailed
     as you like, though it must be based on visual or audible conditions that occur
     within 30 feet of the area. For example, you could create an illusion of
     yourself to appear and warn off others who attempt to open a trapped door, or
     you could set the illusion to trigger only when a creature says the correct word
-     or phrase.
+    or phrase.
 
     Physical interaction with the image reveals it to be an illusion,
     because things can pass through it. A creature that uses its action to examine
@@ -738,69 +764,72 @@ class ProgrammedIllusion(Spell):
     illusion for what it is, the creature can see through the image, and any noise
     it makes sounds hollow to the creature.
     """
+
     name = "Programmed Illusion"
     level = 6
     casting_time = "1 action"
     casting_range = "120 feet"
-    components = ('V', 'S', 'M')
-    materials = """A bit of fleece and jade dust worth at least 25 gp"""
+    components = ("V", "S", "M")
+    materials = "A bit of fleece and jade dust worth at least 25 gp"
     duration = "Until dispelled"
     ritual = False
     magic_school = "Illusion"
-    classes = ('Bard', 'Wizard')
+    classes = ("Bard", "Wizard")
 
 
 class ProjectImage(Spell):
     """You create an illusory copy of yourself that lasts for the duration.
     The copy
     can appear at any location within range that you have seen before, regardless of
-     intervening obstacles. The illusion looks and sounds like you but is
+    intervening obstacles. The illusion looks and sounds like you but is
     intangible. If the illusion takes any damage, it disappears, and the spell ends.
 
 
     You can use your action to move this illusion up to twice your speed, and make
-     it gesture, speak, and behave in whatever way you choose. It mimics your
+    it gesture, speak, and behave in whatever way you choose. It mimics your
     mannerisms perfectly.
 
     You can see through its eyes and hear through its ears as
-     if you were in its space. On your turn as a bonus action, you can switch from
+    if you were in its space. On your turn as a bonus action, you can switch from
     using its senses to using your own, or back again. While you are using its
     senses, you are blinded and deafened in regard to your own surroundings.
 
 
     Physical interaction with the image reveals it to be an illusion, because things
-     can pass through it. A creature that uses its action to examine the image can
+    can pass through it. A creature that uses its action to examine the image can
     determine that it is an illusion with a successful Intelligence (Investigation)
     check against your spell save DC. If a creature discerns the illusion for what
     it is, the creature can see through the image, and any noise it makes sounds
     hollow to the creature.
     """
+
     name = "Project Image"
     level = 7
     casting_time = "1 action"
     casting_range = "500 miles"
-    components = ('V', 'S', 'M')
-    materials = """A small replica of you made from materials worth at least 5 gp"""
+    components = ("V", "S", "M")
+    materials = "A small replica of you made from materials worth at least 5 gp"
     duration = "Concentration, up to 1 day"
     ritual = False
     magic_school = "Illusion"
-    classes = ('Bard', 'Wizard')
+    classes = ("Bard", "Wizard")
 
 
 class ProtectionFromEnergy(Spell):
     """For the duration, the willing creature you touch has resistance to one damage
     type of your choice: acid, cold, fire, lightning, or thunder.
     """
+
     name = "Protection From Energy"
     level = 3
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 hour"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric', 'Druid', 'Ranger', 'Sorcerer', 'Wizard')
+    classes = ("Cleric", "Druid", "Ranger", "Sorcerer", "Wizard")
 
 
 class ProtectionFromEvilAndGood(Spell):
@@ -812,79 +841,83 @@ class ProtectionFromEvilAndGood(Spell):
     have disadvantage on attack rolls against the target. The target also can't be
     charmed, frightened, or possessed by them. If the target is already charmed,
     frightened, or possessed by such a creature, the target has advantage on any new
-     saving throw against the relevant effect.
+    saving throw against the relevant effect.
     """
+
     name = "Protection From Evil And Good"
     level = 1
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """Holy water or powdered silver and iron, which the spell consumes"""
+    components = ("V", "S", "M")
+    materials = "Holy water or powdered silver and iron, which the spell consumes"
     duration = "Concentration, up to 10 minutes"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric', 'Paladin', 'Warlock', 'Wizard')
+    classes = ("Cleric", "Paladin", "Warlock", "Wizard")
 
 
 class ProtectionFromPoison(Spell):
     """You touch a creature. If it is poisoned, you neutralize the poison. If more than
-     one poison afflicts the target, you neutralize one poison that you know is
+    one poison afflicts the target, you neutralize one poison that you know is
     present, or you neutralize one at random.
 
     For the duration, the target has
     advantage on saving throws against being poisoned, and it has resistance to
     poison damage.
     """
+
     name = "Protection From Poison"
     level = 2
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "1 hour"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric', 'Druid', 'Paladin', 'Ranger')
+    classes = ("Cleric", "Druid", "Paladin", "Ranger")
 
 
 class PsychicScream(Spell):
     """You unleash the power of your mind to blast the intellect of up to ten creatures
-     of your choice that you can see within range. Creatures that have an
+    of your choice that you can see within range. Creatures that have an
     Intelligence score of 2 or lower are unaffected.
     Each target must make an
     Intelligence saving throw. On a failed save, a target takes 14d6 psychic damage
     and is stunned. On a successful save, a target takes half as much damage and
     isn't stunned. If a target is killed by this damage, its head explodes, assuming
-     it has one.
+    it has one.
     A stunned target can make an Intelligence saving throw at the end
     of each of its turns. On a successful save, the stunning effect ends.
     """
+
     name = "Psychic Scream"
     level = 9
     casting_time = "1 action"
     casting_range = "90 feet"
-    components = ('S',)
-    materials = """"""
+    components = ("S",)
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Enchantment"
-    classes = ('Bard', 'Sorcerer', 'Warlock', 'Wizard')
+    classes = ("Bard", "Sorcerer", "Warlock", "Wizard")
 
 
 class PurifyFoodAndDrink(Spell):
     """All nonmagical food and drink within a 5-foot-radius sphere centered on a point
     of your choice within range is purified and rendered free of poison and disease.
     """
+
     name = "Purify Food And Drink"
     level = 1
     casting_time = "1 action"
     casting_range = "10 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = True
     magic_school = "Transmutation"
-    classes = ('Cleric', 'Druid', 'Paladin')
+    classes = ("Cleric", "Druid", "Paladin")
 
 
 class Pyrotechnics(Spell):
@@ -899,15 +932,14 @@ class Pyrotechnics(Spell):
     20-foot radius, moving around corners. The area of the smoke is heavily
     obscured. The smoke persists for 1 minute or until a strong wind disperses it.
     """
+
     name = "Pyrotechnics"
     level = 2
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Bard', 'Sorcerer', 'Wizard')
-
-
+    classes = ("Bard", "Sorcerer", "Wizard")
