@@ -7,8 +7,8 @@ class RaiseDead(Spell):
     rejoin the body, the creature returns to life with 1 hit point.
 
     This spell also
-     neutralizes any poison and cures nonmagical diseases that affected the creature
-     at the time it died. This spell doesn't, however, remove magical diseases,
+    neutralizes any poison and cures nonmagical diseases that affected the creature
+    at the time it died. This spell doesn't, however, remove magical diseases,
     curses, or similar effects; if these aren't first removed prior to casting the
     spell, they take effect when the creature returns to life. The spell can't
     return an undead creature to life.
@@ -19,20 +19,21 @@ class RaiseDead(Spell):
     automatically fails.
 
     Coming back from the dead is an ordeal. The target takes a
-     -4 penalty to all attack rolls, saving throws, and ability checks. Every time
+    -4 penalty to all attack rolls, saving throws, and ability checks. Every time
     the target finishes a long rest, the penalty is reduced by 1 until it
     disappears.
     """
+
     name = "Raise Dead"
     level = 5
     casting_time = "1 hour"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A diamond worth at least 500 gp, which the spell consumes"""
+    components = ("V", "S", "M")
+    materials = "A diamond worth at least 500 gp, which the spell consumes"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Bard', 'Cleric', 'Paladin')
+    classes = ("Bard", "Cleric", "Paladin")
 
 
 class RarysTelepathicBond(Spell):
@@ -46,16 +47,17 @@ class RarysTelepathicBond(Spell):
     is possible over any distance, though it can't extend to other planes of
     existence.
     """
+
     name = "Rarys Telepathic Bond"
     level = 5
     casting_time = "1 action"
     casting_range = "30 feet"
-    components = ('V', 'S', 'M')
-    materials = """Pieces of eggshell from two different kinds of creatures"""
+    components = ("V", "S", "M")
+    materials = "Pieces of eggshell from two different kinds of creatures"
     duration = "1 hour"
     ritual = True
     magic_school = "Divination"
-    classes = ('Wizard',)
+    classes = ("Wizard",)
 
 
 class RayOfEnfeeblement(Spell):
@@ -68,37 +70,39 @@ class RayOfEnfeeblement(Spell):
     At the end of each of the target's turns, it can make a
     Constitution saving throw against the spell. On a success, the spell ends.
     """
+
     name = "Ray Of Enfeeblement"
     level = 2
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Warlock', 'Wizard')
+    classes = ("Warlock", "Wizard")
 
 
 class RayOfFrost(Spell):
     """A frigid beam of blue-white light streaks toward a creature within range. Make a
-     ranged spell attack against the target. On a hit, it takes 1d8 cold damage, and
-     its speed is reduced by 10 feet until the start of your next turn.
+    ranged spell attack against the target. On a hit, it takes 1d8 cold damage, and
+    its speed is reduced by 10 feet until the start of your next turn.
 
     At Higher
     Levels: The spell's damage increases by 1d8 when you reach 5th level (2d8), 11th
-     level (3d8), and 17th level (4d8).
+    level (3d8), and 17th level (4d8).
     """
+
     name = "Ray Of Frost"
     level = 0
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Evocation"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class RayOfSickness(Spell):
@@ -106,45 +110,47 @@ class RayOfSickness(Spell):
 
     Make a ranged spell attack against the target. On a hit, the target takes 2d8
     poison damage and must make a Constitution saving throw. On a failed save, it is
-     also poisoned until the end of your next turn.
+    also poisoned until the end of your next turn.
 
-    At Higher Levels: When you cast
-     this spell using a spell slot of 2nd level or higher, the damage increases by
+    **At Higher Levels:** When you cast
+    this spell using a spell slot of 2nd level or higher, the damage increases by
     1d8 for each slot level above 1st.
     """
+
     name = "Ray Of Sickness"
     level = 1
     casting_time = "1 action"
     casting_range = "60 feet"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Sorcerer', 'Wizard')
+    classes = ("Sorcerer", "Wizard")
 
 
 class Regenerate(Spell):
     """You touch a creature and stimulate its natural healing ability.
     The target
     regains 4d8 + 15 hit points. For the duration of the spell, the target regains 1
-     hit point at the start of each of its turns (10 hit points each minute).
+    hit point at the start of each of its turns (10 hit points each minute).
 
     The
     target's severed body members (fingers, legs, tails, and so on), if any, are
     restored after 2 minutes. If you have the severed part and hold it to the stump,
-     the spell instantaneously causes the limb to knit to the stump.
+    the spell instantaneously causes the limb to knit to the stump.
     """
+
     name = "Regenerate"
     level = 7
     casting_time = "1 minute"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A prayer wheel and holy water"""
+    components = ("V", "S", "M")
+    materials = "A prayer wheel and holy water"
     duration = "1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Bard', 'Cleric', 'Druid')
+    classes = ("Bard", "Cleric", "Druid")
 
 
 class Reincarnate(Spell):
@@ -176,39 +182,43 @@ class Reincarnate(Spell):
     69-76 Halfling, stout
     77-96 Human
     97-00
-     Tiefling
+    Tiefling
 
     The reincarnated creature recalls its former life and experiences. It
-     retains the capabilities it had in its original form, except it exchanges its
+    retains the capabilities it had in its original form, except it exchanges its
     original race for the new one and changes its racial traits accordingly.
     """
+
     name = "Reincarnate"
     level = 5
     casting_time = "1 hour"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """Rare oils and unguents worth at least 1,000 gp, which the spell consumes"""
+    components = ("V", "S", "M")
+    materials = (
+        """Rare oils and unguents worth at least 1,000 gp, which the spell consumes"""
+    )
     duration = "Instantaneous"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Druid',)
+    classes = ("Druid",)
 
 
 class RemoveCurse(Spell):
     """At your touch, all curses affecting one creature or object end. If the object is
-     a cursed magic item, its curse remains, but the spell breaks its owner's
+    a cursed magic item, its curse remains, but the spell breaks its owner's
     attunement to the object so it can be removed or discarded.
     """
+
     name = "Remove Curse"
     level = 3
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S')
-    materials = """"""
+    components = ("V", "S")
+    materials = ""
     duration = "Instantaneous"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric', 'Paladin', 'Warlock', 'Wizard')
+    classes = ("Cleric", "Paladin", "Warlock", "Wizard")
 
 
 class Resistance(Spell):
@@ -216,16 +226,17 @@ class Resistance(Spell):
     a d4 and add the number rolled to one saving throw of its choice. It can roll
     the die before or after the saving throw. The spell then ends.
     """
+
     name = "Resistance"
     level = 0
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A miniature cloak"""
+    components = ("V", "S", "M")
+    materials = "A miniature cloak"
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Abjuration"
-    classes = ('Cleric', 'Druid')
+    classes = ("Cleric", "Druid")
 
 
 class Resurrection(Spell):
@@ -236,7 +247,7 @@ class Resurrection(Spell):
     This spell neutralizes any
     poisons and cures normal diseases afflicting the creature when it died. It
     doesn't, however, remove magical diseases, curses, and the like; if such affects
-     aren't removed prior to casting the spell, they afflict the target on its
+    aren't removed prior to casting the spell, they afflict the target on its
     return to life.
 
     This spell closes all mortal wounds and restores any missing
@@ -248,27 +259,28 @@ class Resurrection(Spell):
 
 
     Casting this spell to restore life to a creature that has been dead for one year
-     or longer taxes you greatly. Until you finish a long rest, you can't cast
+    or longer taxes you greatly. Until you finish a long rest, you can't cast
     spells again, and you have disadvantage on all attack rolls, ability checks, and
-     saving throws.
+    saving throws.
     """
+
     name = "Resurrection"
     level = 7
     casting_time = "1 hour"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """A diamond worth at least 1,000 gp, which the spell consumes"""
+    components = ("V", "S", "M")
+    materials = "A diamond worth at least 1,000 gp, which the spell consumes"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Bard', 'Cleric')
+    classes = ("Bard", "Cleric")
 
 
 class ReverseGravity(Spell):
     """This spell reverses gravity in a 50-foot-radius, 100-foot high cylinder centered
-     on a point within range.
+    on a point within range.
     All creatures and objects that aren't somehow anchored
-     to the ground in the area fall upward and reach the top of the area when you
+    to the ground in the area fall upward and reach the top of the area when you
     cast this spell. A creature can make a Dexterity saving throw to grab onto a
     fixed object it can reach, thus avoiding the fall.
 
@@ -281,33 +293,35 @@ class ReverseGravity(Spell):
     At the end of the duration, affected
     objects and creatures fall back down.
     """
+
     name = "Reverse Gravity"
     level = 7
     casting_time = "1 action"
     casting_range = "100 feet"
-    components = ('V', 'S', 'M')
-    materials = """A lodestone and iron filings"""
+    components = ("V", "S", "M")
+    materials = "A lodestone and iron filings"
     duration = "Concentration, up to 1 minute"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Druid', 'Sorcerer', 'Wizard')
+    classes = ("Druid", "Sorcerer", "Wizard")
 
 
 class Revivify(Spell):
     """You touch a creature that has died within the last minute. That creature returns
-     to life with 1 hit point. This spell can't return to life a creature that has
+    to life with 1 hit point. This spell can't return to life a creature that has
     died of old age, nor can it restore any missing body parts.
     """
+
     name = "Revivify"
     level = 3
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """Diamonds worth 300 gp, which the spell consumes"""
+    components = ("V", "S", "M")
+    materials = "Diamonds worth 300 gp, which the spell consumes"
     duration = "Instantaneous"
     ritual = False
     magic_school = "Necromancy"
-    classes = ('Cleric', 'Paladin')
+    classes = ("Cleric", "Paladin")
 
 
 class RopeTrick(Spell):
@@ -323,20 +337,19 @@ class RopeTrick(Spell):
 
     Attacks and spells can't cross
     through the entrance into or out of the extradimensional space, but those inside
-     can see out of it as if through a 3-foot-by-5-foot window centered on the rope.
+    can see out of it as if through a 3-foot-by-5-foot window centered on the rope.
 
 
     Anything inside the extradimensional space drops out when the spell ends.
     """
+
     name = "Rope Trick"
     level = 2
     casting_time = "1 action"
     casting_range = "Touch"
-    components = ('V', 'S', 'M')
-    materials = """Powdered corn extract and a twisted loop of parchment"""
+    components = ("V", "S", "M")
+    materials = "Powdered corn extract and a twisted loop of parchment"
     duration = "1 hour"
     ritual = False
     magic_school = "Transmutation"
-    classes = ('Wizard',)
-
-
+    classes = ("Wizard",)
